Name:           wiredtiger
Version:        2.5.1
Release:        1%{?dist}
Summary:        WiredTiger data storage engine
# http://source.wiredtiger.com/develop/license.html
License:        (GPLv2 or GPLv3) and MIT and BSD
URL:            http://www.wiredtiger.com/
Source0:        https://github.com/wiredtiger/wiredtiger/releases/download/%{version}/%{name}-%{version}.tar.bz2

BuildRequires:  libtool
BuildRequires:  doxygen
BuildRequires:  swig
BuildRequires:  java-devel
BuildRequires:  python-devel
BuildRequires:  snappy-devel
BuildRequires:  zlib-devel
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description
WiredTiger is a data storage engine that provides APIs for efficiently
storing data in highly concurrent applications. It includes functionality
for automatically maintaining indexes. It implements both row and column
store formats - so that all types of data can be stored space efficiently.

WiredTiger is a library that can be accessed via C, Python and Java APIs.
%package libs
Summary:        The shared libraries provided by WiredTiger

%description libs
The wiredtiger-libs package provides the WiredTiger shared libraries.

%package devel
Summary:        WiredTiger development files
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}
Requires:       %{name}-python%{?_isa} = %{version}-%{release}
Requires:       %{name}-java%{?_isa} = %{version}-%{release}

%description devel
The wiredtiger-libs package provides the WiredTiger development files.

%package python
Summary:        Python bindings for WiredTiger
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description python
The wiredtiger-python package provides WiredTiger python API.

%package java
Summary:        Java bindings for WiredTiger
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description java
The wiredtiger-java package provides WiredTiger java API.


%prep
%autosetup

./autogen.sh
# Disable -release for libtool -> disable building libwiredtiger-VERSION.so
sed -i -r "s|^(libwiredtiger_la_LDFLAGS =) .*|\1|" Makefile.am

# Fix installing python files into BUILDROOT
sed -i -r "s|(\(PYTHON_INSTALL_ARG\))|\1 --no-compile --install-dir %{buildroot}%{python_sitelib}|" lang/python/Makefile.am

%build
%configure --disable-static --with-builtins=zlib,snappy --enable-python --enable-java JAR="%{java_home}/bin/jar"

# Stop the build setting up an rpath
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

make %{?_smp_mflags} CFLAGS="%{optflags}"


%install
%make_install

# Move python library into wiredtiger directory
mv %{buildroot}%{python_sitelib}/_%{name}.so %{buildroot}%{python_sitelib}/%{name}

# Put java libs and .jar into right location
mv %{buildroot}%{_javadir}/%{name}-%{version}/lib* %{buildroot}%{_libdir}
mv %{buildroot}%{_javadir}/%{name}-%{version}/%{name}.jar %{buildroot}%{_javadir}/
rmdir %{buildroot}%{_javadir}/%{name}-%{version}

# Remove .la files
rm -f %{buildroot}%{_libdir}/lib%{name}.la
rm -f %{buildroot}%{_libdir}/lib%{name}_java.la


%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%post java -p /sbin/ldconfig
%postun java -p /sbin/ldconfig


%files
%{_bindir}/wt
%{_mandir}/man1/wt.1.gz

%files libs
%doc README NEWS
%license LICENSE
%{_libdir}/lib%{name}.so.*
%{_mandir}/man3/%{name}.3.gz

%files devel
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/*

%files python
%dir %{python_sitelib}/%{name}
%{python_sitelib}/%{name}/*

%files java
%{_libdir}/lib%{name}_java.so*
%{_javadir}/%{name}.jar

%changelog
* Thu Mar 12 2015 Marek Skalicky <mskalick@redhat.com> - 2.5.1-1
- Initial packaging
